@@ -121,7 +121,7 @@
 #define HAVE_LIBCRYPT 1
 /* #undef HAVE_LIBMTMALLOC */
 /* #undef HAVE_LIBWRAP */
-/* #undef HAVE_SYSTEMD */
+#define HAVE_SYSTEMD 1
 /* Does "struct timespec" have a "sec" and "nsec" field? */
 /* #undef HAVE_TIMESPEC_TS_SEC */
 
@@ -225,6 +225,7 @@
 #define HAVE_PREAD 1
 /* #undef HAVE_PAUSE_INSTRUCTION */
 /* #undef HAVE_FAKE_PAUSE_INSTRUCTION */
+/* #undef HAVE_HMT_PRIORITY_INSTRUCTION */
 /* #undef HAVE_RDTSCLL */
 /* #undef HAVE_READ_REAL_TIME */
 /* #undef HAVE_PTHREAD_ATTR_CREATE */
@@ -640,16 +641,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 1
-#define MYSQL_VERSION_PATCH 13
+#define MYSQL_VERSION_PATCH 16
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.1.13"
+#define PACKAGE_STRING "MySQL Server 10.1.16"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.1.13"
-#define VERSION "10.1.13"
+#define PACKAGE_VERSION "10.1.16"
+#define VERSION "10.1.16"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
